from distutils.core import setup

setup(
    name = "wjtestPrint",
    version = "1.2.0",
    py_modules = ["WJTestPrint"],
    author = "wenjie",
    author_email = "826834678@qq.com",
    url = "http://www.baidu.com",
    description = "test",
    )
